@@ -34,14 +34,18 @@ def clitest(name: str):
 
 @cli.command()
 def extract4ddl(ipath: str, opath=None):
-    """解析ddl"""
+    """解析ddl
+    nesc extract4ddl '/Users/yuanjie/Desktop/notebook/0_TODO/mot_part.sql'
+    """
     from nesc.extract import extract4ddl
     extract4ddl.main(ipath, opath)
 
 
 @cli.command()
 def extract4excel(ipath: str, opath=None):
-    """解析excel"""
+    """解析excel
+    nesc extract4excel "/Users/yuanjie/Downloads/UF20表结构/UF20表结构/UF20表信息.xls"
+    """
     from nesc.extract import extract4excel
     extract4excel.main(ipath, opath)
 
